==> haskell-servant-client-core-0.20.3.0-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-LBpuJtZTi7GKPoMniBKkDG
key:                  servant-client-core-0.20.3.0-LBpuJtZTi7GKPoMniBKkDG
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  6dd579946e3774b21c39345bf55e6930
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-LBpuJtZTi7GKPoMniBKkDG
depends:
    aeson-2.1.2.1-LvJWrHbVhNW5j5NGQeCpIT
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    base64-bytestring-1.2.1.0-2WioaI2OOHv6enJjm95P5G
    bytestring-0.11.5.3 constraints-0.14.2-5QxNhr3qMcl6C3VM5oJRcN
    containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5
    free-5.2-5T6y5mJfoLmDkTYBqYIDd
    http-media-0.8.1.1-9t11Ok4yqJJGDcLjCccVnv
    http-types-0.12.4-Lh5dVrkMNHmKdCH2kircer
    network-uri-2.6.4.2-U3v26HNy1l6rJ9sPiQ7eG
    safe-0.3.21-5ePY1yCKz45qNPHFPlOcS
    servant-0.20.3.0-6CWsyPFrv9e5Pen1Ljqdmk
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-core-0.20.3.0-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-68Uoj1bdn21Wixs2LAhGB
key:                  servant-client-core-0.20.3.0-68Uoj1bdn21Wixs2LAhGB
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  13bf75ff66da6c6db3b2fbd7168fe375
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-68Uoj1bdn21Wixs2LAhGB
depends:
    aeson-2.1.2.1-CM1TyKExMgH6p2KQqrdDHD
    attoparsec-0.14.4-6kRuW0kw4gG3rg1QrsDffs base-4.17.2.1
    base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    base64-bytestring-1.2.1.0-Ag5zZV14qgS6mSqDcHZ0fu
    bytestring-0.11.5.3 constraints-0.14.2-IG2Q4hGIX9I3iciCwIxetH
    containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5
    free-5.2-3jvpHu4MxuHAjRdwVj3rVN
    http-media-0.8.1.1-EAKN9zouIjp6VwHAOK11hP
    http-types-0.12.4-9tb655S6p8NAIcFLCK3aeD
    network-uri-2.6.4.2-FpQrzNLQnEFHV7gxKif8bC
    safe-0.3.21-2QfDol6D5mJHd9hpTIyjO0
    servant-0.20.3.0-G01oCy0t8r8KpjHJ7uxr56
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
